@@ -17,10 +17,17 @@ BEGIN{ unshift(@INC,"../blib/arch"); } # 5.002 gamma needs this
 BEGIN{ unshift(@INC,"../blib/lib");  } # 5.002 gamma needs this
 use RenderMan;
 
-Begin();
+$file = "rgl";
+if ($#ARGV >= 0) { $file = $ARGV[0]; }
+
+Begin($file);
   FrameBegin(1);
-    LightSource(RI_DISTANTLIGHT);
+    Display("cow1.tif", "file", "rgba");
+    Format(640, 480, 1);
+    LightSource(RI_DISTANTLIGHT, { "intensity" => 2, "lightcolor" => [1,1,1],
+                                   "from" => [0,100,-100], "to" => [0,0,0]} );
     Projection(RI_PERSPECTIVE);
+    Sides(2);
     Translate(0, 0, 2);
     WorldBegin();
       Translate(0, -0.75, 0);
@@ -28,11 +35,11 @@ Begin();
 	Rotate(110, 0, 1, 0);
 	Surface("gmarbtile_polish");
 	Color(0, 0.5, 1);
-	ArchiveRecord(RI_STRUCTURE, "Include \"cow.rib\"");
+	ReadArchive("cow.rib");
       AttributeEnd();
       AttributeBegin();
 	Rotate(90, 1, 0, 0);
-	Surface("plank");
+	Surface("superplank");
 	Disk(0, 5, 360);
       AttributeEnd();
     WorldEnd();
